@@ -97,26 +97,6 @@ setClass("cpglm",
     contains = "cplm"
 )
 
-# class of "cpglm", returned by a call to "cpglm" 
-setClass("zcpglm", 
-  representation(
-    coefficients = "list",
-    residuals = "numeric",
-    fitted.values = "numeric", 
-    y = "numeric",
-    offset = "list",
-    prior.weights = "numeric",
-    df.residual = "integer",
-    llik = "numeric",
-    control = "list",
-    p = "numeric",
-    phi ="numeric",
-    converged = "logical",
-    na.action = "NullFunc",
-    vcov = "matrix"),
-    contains = "cplm"
-)
-
 # class "cpglmm" returned from a call of cpglmm
 setClass("cpglmm", 
   representation(
@@ -415,7 +395,7 @@ setMethod("predict", signature(object = "cpglm"),
    }
     if (!is.null(offset)) 
         predictor <- predictor + offset
-    mu <- tweedie(link.power = object@link.power)$linkinv(predictor)
+    mu <- as.vector(tweedie(link.power = object@link.power)$linkinv(predictor))
     type <- match.arg(type)                                                            
     switch(type,link = predictor, response = mu)                                                            
 })
@@ -666,7 +646,7 @@ setMethod("predict", signature(object = "cpglmm"),
     predictor <- as.numeric(X %*% beta + t(Zt)%*% u)
     if (!is.null(offset)) 
         predictor <- predictor + offset
-    mu <- tweedie(link.power = object@link.power)$linkinv(predictor)
+    mu <- as.vector(tweedie(link.power = object@link.power)$linkinv(predictor))
     type <- match.arg(type)
     switch(type,link = predictor, response = mu)   
 })
@@ -790,119 +770,4 @@ print.bcplm <- function(x, digits = max(3, getOption("digits") - 3)){
   out <- list(fixef = coefs, 
               VarCorr = if (dims["n.u"]) REmat else list())
   invisible(out)
-}
-
-
-################################################
-# methods defined for zcpglm 
-################################################
-         
-setMethod("coef",
-  signature(object = "zcpglm"),
-  function (object, ...) object@coefficients
-)
-
-setMethod("residuals",
-  signature(object = "zcpglm"), 
-  function(object, ...) object@residuals  
-)
-
-setMethod("resid",
-  signature(object = "zcpglm"), 
-  function(object, ...) residuals(object)
-)
-
-# generate fitted values on the original scale
-setMethod("fitted",
-  signature(object = "zcpglm"),
-  function (object, ...)  object@fitted.values
-)
-	
-setMethod("summary", signature(object = "zcpglm"),
-	function(object, ...){ 
-    nbz <- length(coef(object)$zero)
-    nbt <- length(coef(object)$tweedie)
-    se <- sqrt(diag(vcov(object)))
-    coef <- unlist(coef(object))
-    zstat <- coef / se
-    pval <- 2 * pnorm(-abs(zstat))
-    coef <- cbind(coef, se, zstat, pval)
-    colnames(coef) <- c("Estimate", "Std. Error", "z value", "Pr(>|z|)")
-    rownames(coef) <- c(names(coef(object)$zero), names(coef(object)$tweedie))
-    
-    coef.table <- list()
-    coef.table$zero <- coef[1:nbz, , drop = FALSE]
-    coef.table$tweedie <- coef[(nbz + 1):(nbz + nbt), , drop = FALSE]
-    
-    keep <- match(c("llik", "contrasts", "df.residual",  
-        "na.action", "vcov"), names(object), 0L)
-    
-    out <- list(llik = object@llik, contrasts = object@contrasts, 
-                df.residual = object@df.residual, vcov = object @vcov, 
-                na.action = object@na.action, coefficients = coef.table,
-                call = object@call, phi = object@phi, p = object@p)
-    .print.zcpglm.summary(out)  
-	}
-)
-                    
-.print.zcpglm.summary<-function(x,digits = max(3, getOption("digits") - 3),
-                               signif.stars = getOption("show.signif.stars"), ...){
-  
-    cat("\nCall:\n", paste(deparse(x$call), sep = "\n", collapse = "\n"), 
-        "\n\n", sep = "")
-    cat(paste("Zero-inflation model coefficients:\n"))
-    printCoefmat(x$coefficients$zero, digits = digits, signif.stars = signif.stars, 
-            na.print = "NA", signif.legend = FALSE)
-    cat(paste("\nCompound Poisson model coefficients:\n"))
-    printCoefmat(x$coefficients$tweedie, digits = digits, signif.stars = signif.stars, 
-            na.print = "NA")    
-    cat("\nEstimated dispersion parameter:",  
-        format(x$phi, digits = max(5, digits + 1))) 
-    cat("\nEstimated index parameter:",  
-        format(x$p, digits = max(5, digits + 1)),"\n") 
-    if (nzchar(mess <- naprint(x$na.action))) 
-        cat("  (", mess, ")\n", sep = "")
-    invisible(x)
-}
-
-
-setMethod("predict", signature(object = "zcpglm"),
-  function (object, newdata, type = c("response", "zero", "tweedie"), 
-                    na.action = na.pass, ...) {
-  call <- object$call
-  ttz <- attr(object@model.frame$zero, "terms")
-  ttt <- attr(object@model.frame$tweedie, "terms")
-  Termsz <- delete.response(ttz)
-  Termst <- delete.response(ttt)
-  xlevz <- .getXlevels(Termsz, object@model.frame$zero)
-  xlevt <- .getXlevels(Termst, object@model.frame$tweedie)  
-  mz <- model.frame(Termsz, newdata, na.action = na.action, xlev = xlevz)
-  mt <- model.frame(Termst, newdata, na.action = na.action, xlev = xlevt)
-  Xz <- model.matrix(Termsz, mz, contrasts.arg = object$contrasts)
-  Xt <- model.matrix(Termst, mt, contrasts.arg = object$contrasts)
-  offt <- offz <- rep(0, nrow(Xz))
-  if (!is.null(off.num <- attr(ttz, "offset"))) 
-    for (i in off.num) 
-        offz <- offz + eval(attr(ttz, "variables")[[i + 1]], newdata)
-  if (!is.null(off.num <- attr(ttt, "offset"))) 
-    for (i in off.num) 
-      offt <- offt + eval(attr(ttt, "variables")[[i + 1]], newdata)
-  if (!is.null(object$call$offset)) {
-      off <- eval(object$call$offset, newdata)
-      offz <- offz + off
-      offt <- offt + off 
-  }
-  
-  link.power <- make.link.power(object$link.power)
-  tw <- tweedie(link.power = link.power)                 
-  logit <- binomial()
-  
-  betaz <- object$coefficients$zero
-  betat <- object$coefficients$tweedie
-  muz <- logit$linkinv(Xz %*% betaz + offz)
-  mut <- tw$linkinv(Xt %*% betat + offt)
-  mu <- as.numeric((1 - muz) * mut)  
-  
-  type <- match.arg(type)                                                            
-  switch(type, response = mu, zero = muz, tweedie = mut)                                                            
-})
\ No newline at end of file
+}
\ No newline at end of file
